@@ -8,11 +8,11 @@
   bill@newbreedsoftware.com
   http://www.newbreedsoftware.com/vectoroids/
   
-  November 30, 2001 - January 3, 2002
+  November 30, 2001 - April 13, 2002
 */
 
-#define VER_VERSION "1.0.7"
-#define VER_DATE "2002.01.03"
+#define VER_VERSION "1.0.8"
+#define VER_DATE "2002.04.13"
 #define STATE_FORMAT_VERSION "2001.12.01"
 
 
@@ -33,19 +33,35 @@
 
 /* Constraints: */
 
-#define NUM_BULLETS 2
+#ifndef EMBEDDED
+  #define NUM_BULLETS 2
+#else
+  #define NUM_BULLETS 3
+#endif
+
 #define NUM_ASTEROIDS 20
 #define NUM_BITS 50
-#define AST_RADIUS 10
+
 #define AST_SIDES 6
-#define SHIP_RADIUS 20
+#ifndef EMBEDDED
+  #define AST_RADIUS 10
+  #define SHIP_RADIUS 20
+#else
+  #define AST_RADIUS 7
+  #define SHIP_RADIUS 12
+#endif
 
 #define ZOOM_START 40
 #define ONEUP_SCORE 10000
-
 #define FPS 50
-#define WIDTH 480
-#define HEIGHT 480
+
+#ifndef EMBEDDED
+  #define WIDTH 480
+  #define HEIGHT 480
+#else
+  #define WIDTH 240
+  #define HEIGHT 320
+#endif
 
 
 
@@ -1210,7 +1226,13 @@ int game(void)
 	  if (use_sound)
 	    {
 	      if (!Mix_Playing(CHAN_THRUST))
-		Mix_PlayChannel(CHAN_THRUST, sounds[SND_THRUST], -1);
+		{
+#ifndef EMBEDDED
+		  Mix_PlayChannel(CHAN_THRUST, sounds[SND_THRUST], -1);
+#else
+		  Mix_PlayChannel(-1, sounds[SND_THRUST], 0);
+		}
+#endif
 	    }
 #endif
 	}
@@ -1231,7 +1253,11 @@ int game(void)
 	  if (use_sound)
 	    {
 	      if (Mix_Playing(CHAN_THRUST))
-		Mix_HaltChannel(CHAN_THRUST);
+		{
+#ifndef EMBEDDED
+		  Mix_HaltChannel(CHAN_THRUST);
+#endif
+		}
 	    }
 #endif
 	}
@@ -1291,7 +1317,7 @@ int game(void)
       
       
       /* Erase screen: */
-      
+
       SDL_BlitSurface(bkgd, NULL, screen, NULL);
 
 
@@ -1440,7 +1466,11 @@ int game(void)
 		  if (use_sound)
 		    {
 		      if (Mix_Playing(CHAN_THRUST))
-			Mix_HaltChannel(CHAN_THRUST);
+			{
+#ifndef EMBEDDED
+			  Mix_HaltChannel(CHAN_THRUST);
+#endif
+			}
 		    }
 #endif
 		  
@@ -1963,7 +1993,7 @@ void setup(int argc, char * argv[])
   
   if (fullscreen)
     {
-      screen = set_vid_mode(SDL_FULLSCREEN);
+      screen = set_vid_mode(SDL_FULLSCREEN | SDL_HWSURFACE);
       
       if (screen == NULL)
         {
@@ -1993,7 +2023,9 @@ void setup(int argc, char * argv[])
   
   /* Load background image: */
 
+#ifndef EMBEDDED
   tmp = IMG_Load(DATA_PREFIX "images/redspot.jpg");
+
   if (tmp == NULL)
     {
       fprintf(stderr,
@@ -2017,6 +2049,34 @@ void setup(int argc, char * argv[])
   
   SDL_FreeSurface(tmp);
 
+#else
+  
+  tmp = SDL_LoadBMP(DATA_PREFIX "images/redspot-e.bmp");
+
+  if (tmp == NULL)
+    {
+      fprintf(stderr,
+	      "\nError: I could not open the background image:\n"
+	      DATA_PREFIX "images/redspot-e.bmp\n"
+	      "The Simple DirectMedia error that occured was:\n"
+	      "%s\n\n", SDL_GetError());
+      exit(1);
+    }
+  
+  bkgd = SDL_DisplayFormat(tmp);
+  if (bkgd == NULL)
+    {
+      fprintf(stderr,
+	      "\nError: I couldn't convert the background image"
+	      "to the display format!\n"
+	      "The Simple DirectMedia error that occured was:\n"
+	      "%s\n\n", SDL_GetError());
+      exit(1);
+    }
+  
+  SDL_FreeSurface(tmp);
+#endif
+
 
 #ifndef NOSOUND
   /* Init sound: */
@@ -2077,6 +2137,7 @@ void setup(int argc, char * argv[])
 
 void seticon(void)
 {
+#ifndef EMBEDDED
   int masklen;
   Uint8 * mask;
   SDL_Surface * icon;
@@ -2111,6 +2172,7 @@ void seticon(void)
   
   free(mask);
   SDL_FreeSurface(icon);
+#endif
 }
 
 
@@ -2193,8 +2255,11 @@ void sdl_drawline(int x1, int y1, color_type c1,
 		  int x2, int y2, color_type c2)
 {
   int dx, dy;
+#ifndef EMBEDDED
   float cr, cg, cb, rd, gd, bd;
+#endif
   float m, b;
+
   
   if (clip(&x1, &y1, &x2, &y2))
     {
@@ -2210,7 +2275,8 @@ void sdl_drawline(int x1, int y1, color_type c1,
             dx = 1;
           else
             dx = -1;
-          
+         
+#ifndef EMBEDDED
           cr = c1.r;
           cg = c1.g;
           cb = c1.b;
@@ -2218,20 +2284,29 @@ void sdl_drawline(int x1, int y1, color_type c1,
           rd = (float) (c2.r - c1.r) / (float) (x2 - x1) * dx;
           gd = (float) (c2.g - c1.g) / (float) (x2 - x1) * dx;
           bd = (float) (c2.b - c1.b) / (float) (x2 - x1) * dx;
+#endif
           
           while (x1 != x2)
             {
               y1 = m * x1 + b;
               y2 = m * (x1 + dx) + b;
               
+#ifndef EMBEDDED
               drawvertline(x1, y1, mkcolor(cr, cg, cb),
                            y2, mkcolor(cr + rd, cg + gd, cb + bd));
-              
+#else
+              drawvertline(x1, y1, mkcolor(c1.r, c1.g, c1.b),
+                           y2, mkcolor(c1.r, c1.g, c1.b));
+#endif
+	      
               x1 = x1 + dx;
               
+
+#ifndef EMBEDDED
               cr = cr + rd;
               cg = cg + gd;
               cb = cb + bd;
+#endif
             }
         }
       else
@@ -2244,21 +2319,24 @@ void sdl_drawline(int x1, int y1, color_type c1,
 
 int clip(int * x1, int * y1, int * x2, int * y2)
 {
+#ifndef EMBEDDED
+
   float fx1, fx2, fy1, fy2, tmp;
+  float m;
   unsigned char code1, code2;
   int done, draw, swapped;
   unsigned char ctmp;
-  float m;
-  
   fx1 = (float) *x1;
   fy1 = (float) *y1;
   fx2 = (float) *x2;
   fy2 = (float) *y2;
+
   
   done = FALSE;
   draw = FALSE;
   m = 0;
   swapped = FALSE;
+
   
   while (!done)
     {
@@ -2335,13 +2413,25 @@ int clip(int * x1, int * y1, int * x2, int * y2)
       fy2 = tmp;
     }
   
-  
+ 
   *x1 = (int) fx1;
   *y1 = (int) fy1;
   *x2 = (int) fx2;
   *y2 = (int) fy2;
-  
+
   return(draw);
+#else
+
+  if (*x1 < 0 || *x1 >= WIDTH ||
+      *y1 < 0 || *y1 >= HEIGHT ||
+      *x2 < 0 || *x2 >= WIDTH ||
+      *y2 < 0 || *y2 >= HEIGHT)
+    return FALSE;
+  else
+    return TRUE;
+      
+
+#endif
 }
 
 
@@ -2373,7 +2463,11 @@ void drawvertline(int x, int y1, color_type c1,
                   int y2, color_type c2)
 {
   int tmp, dy;
+#ifndef EMBEDDED
   float cr, cg, cb, rd, gd, bd;
+#else
+  int cr, cg, cb;
+#endif
   
   if (y1 > y2)
     {
@@ -2381,6 +2475,7 @@ void drawvertline(int x, int y1, color_type c1,
       y1 = y2;
       y2 = tmp;
       
+#ifndef EMBEDDED
       tmp = c1.r;
       c1.r = c2.r;
       c2.r = tmp;
@@ -2392,12 +2487,14 @@ void drawvertline(int x, int y1, color_type c1,
       tmp = c1.b;
       c1.b = c2.b;
       c2.b = tmp;
+#endif
     }
   
   cr = c1.r;
   cg = c1.g;
   cb = c1.b;
   
+#ifndef EMBEDDED
   if (y1 != y2)
     {
       rd = (float) (c2.r - c1.r) / (float) (y2 - y1);
@@ -2410,6 +2507,7 @@ void drawvertline(int x, int y1, color_type c1,
       gd = 0;
       bd = 0;
     }
+#endif
   
   for (dy = y1; dy <= y2; dy++)
     {
@@ -2420,9 +2518,11 @@ void drawvertline(int x, int y1, color_type c1,
                                          (Uint8) cg,
                                          (Uint8) cb));
 
+#ifndef EMBEDDED
       cr = cr + rd;
       cg = cg + gd;
       cb = cb + bd;
+#endif
     } 
 }
 
@@ -2611,12 +2711,18 @@ void add_bit(int x, int y, int xm, int ym)
 void draw_asteroid(int size, int x, int y, int angle, shape_type * shape)
 {
   int i, b1, b2;
+  int div;
   
+#ifndef EMBEDDED
+  div = 240;
+#else
+  div = 120;
+#endif
   
   for (i = 0; i < AST_SIDES - 1; i++)
     {
-      b1 = (((shape[i].angle + angle) % 180) * 255) / 240;
-      b2 = (((shape[i + 1].angle + angle) % 180) * 255) / 240;
+      b1 = (((shape[i].angle + angle) % 180) * 255) / div;
+      b2 = (((shape[i + 1].angle + angle) % 180) * 255) / div;
       
       draw_segment((size * (AST_RADIUS - shape[i].radius)),
 		   shape[i].angle, mkcolor(b1, b1, b1),
@@ -2626,8 +2732,8 @@ void draw_asteroid(int size, int x, int y, int angle, shape_type * shape)
 		   angle);
     }
 
-  b1 = (((shape[AST_SIDES - 1].angle + angle) % 180) * 255) / 240;
-  b2 = (((shape[0].angle + angle) % 180) * 255) / 240;
+  b1 = (((shape[AST_SIDES - 1].angle + angle) % 180) * 255) / div;
+  b2 = (((shape[0].angle + angle) % 180) * 255) / div;
 
   draw_segment((size * (AST_RADIUS - shape[AST_SIDES - 1].radius)),
 	       shape[AST_SIDES - 1].angle, mkcolor(b1, b1, b1),
@@ -2647,13 +2753,17 @@ void playsound(int snd)
 #ifndef NOSOUND
   if (use_sound)
     {
+#ifdef EMBEDDED
+      which = -1;
+#else
       which = (rand() % 3) + CHAN_THRUST;
       for (i = CHAN_THRUST; i < 4; i++)
 	{
 	  if (!Mix_Playing(i))
 	    which = i;
 	}
-      
+#endif
+
       Mix_PlayChannel(which, sounds[snd], 0);
     }
 #endif
@@ -2801,11 +2911,19 @@ void reset_level(void)
   
   for (i = 0; i < (level + 1) && i < 10; i++)
     {
+#ifndef EMBEDDED
       add_asteroid(/* x */ (rand() % 40) + ((WIDTH - 40) * (rand() % 2)),
 		   /* y */ (rand() % HEIGHT),
 		   /* xm */ (rand() % 9) - 4,
 		   /* ym */ ((rand() % 9) - 4) * 4,
 		   /* size */ (rand() % 3) + 2);
+#else
+      add_asteroid(/* x */ (rand() % WIDTH),
+		   /* y */ (rand() % 40) + ((HEIGHT - 40) * (rand() % 2)),
+		   /* xm */ ((rand() % 9) - 4) * 4,
+		   /* ym */ (rand() % 9) - 4,
+		   /* size */ (rand() % 3) + 2);
+#endif
     }
 
 
